==> jc-1.4.0.tar.gz: javax/swing/JRadioButton.h <==
// public class javax.swing.JRadioButton

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class ca3b3fa0c4f0c862 javax_swing_JRadioButton
// @dep_class a2e2e90380605f49 javax_swing_JToggleButton

// header file dependencies
// @dep_header javax_swing_JToggleButton

#include "javax/swing/JToggleButton.h"

#ifndef _JC_javax_swing_JRadioButton_H_
#define _JC_javax_swing_JRadioButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButton$sub_refs	_jc_javax_swing_JRadioButton$sub_refs;
typedef struct _jc_javax_swing_JRadioButton$sub_nonrefs	_jc_javax_swing_JRadioButton$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButton$refs	_jc_javax_swing_JRadioButton$refs;
typedef struct _jc_javax_swing_JRadioButton$nonrefs	_jc_javax_swing_JRadioButton$nonrefs;
typedef struct _jc_javax_swing_JRadioButton$object	_jc_javax_swing_JRadioButton$object;

typedef struct _jc_javax_swing_JRadioButton$fields_struct	_jc_javax_swing_JRadioButton$fields_struct;
typedef const struct _jc_javax_swing_JRadioButton$vmethods	_jc_javax_swing_JRadioButton$vmethods;
typedef const struct _jc_javax_swing_JRadioButton$vtable	_jc_javax_swing_JRadioButton$vtable;
typedef const struct _jc_javax_swing_JRadioButton$vtype	_jc_javax_swing_JRadioButton$vtype;

// Class fields structure
struct _jc_javax_swing_JRadioButton$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRadioButton$fields_struct _jc_javax_swing_JRadioButton$class_fields;

// Constructors
extern void _jc_javax_swing_JRadioButton$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
extern void _jc_javax_swing_JRadioButton$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_JRadioButton$method$_init$14d08bc2d9c96919(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_javax_swing_JRadioButton$method$_init$642d788411804977(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, struct _jc_object *, jboolean);
extern void _jc_javax_swing_JRadioButton$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_javax_swing_JRadioButton$method$_init$87ae54c77b157ee3(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *);
extern void _jc_javax_swing_JRadioButton$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *);
extern void _jc_javax_swing_JRadioButton$method$_init$8431f48b99fcfffb(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *, jboolean);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_JRadioButton$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_JRadioButton$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_JRadioButton$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
extern void _jc_javax_swing_JRadioButton$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButton$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$updateUI$46bebc7909e18fa1;

// Virtual methods structure
struct _jc_javax_swing_JRadioButton$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *);
};

// Vtable
struct _jc_javax_swing_JRadioButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JToggleButton$vmethods	javax_swing_JToggleButton;
	_jc_javax_swing_JRadioButton$vmethods	javax_swing_JRadioButton;
};

// Vtype
struct _jc_javax_swing_JRadioButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButton$refs {
    _jc_javax_swing_JRadioButton$sub_refs	javax_swing_JRadioButton;
    _jc_javax_swing_JToggleButton$sub_refs	javax_swing_JToggleButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JToggleButton$sub_nonrefs	javax_swing_JToggleButton;
    _jc_javax_swing_JRadioButton$sub_nonrefs	javax_swing_JRadioButton;
};

// Object instance structure
struct _jc_javax_swing_JRadioButton$object {
	_jc_javax_swing_JRadioButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButton$vtype	*vtype;
	_jc_javax_swing_JRadioButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButton$vtype _jc_javax_swing_JRadioButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButton$class_object;

#endif	/* _JC_javax_swing_JRadioButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JRadioButton.h <==
// public class javax.swing.JRadioButton

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class ca3b3fa0c4f0c862 javax_swing_JRadioButton
// @dep_class 8ef55e9c27234b4a javax_swing_JToggleButton

// header file dependencies
// @dep_header javax_swing_JToggleButton

#include "javax/swing/JToggleButton.h"

#ifndef _JC_javax_swing_JRadioButton_H_
#define _JC_javax_swing_JRadioButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_JRadioButton$sub_refs	_jc_javax_swing_JRadioButton$sub_refs;
typedef struct _jc_javax_swing_JRadioButton$sub_nonrefs	_jc_javax_swing_JRadioButton$sub_nonrefs;
typedef struct _jc_javax_swing_JRadioButton$refs	_jc_javax_swing_JRadioButton$refs;
typedef struct _jc_javax_swing_JRadioButton$nonrefs	_jc_javax_swing_JRadioButton$nonrefs;
typedef struct _jc_javax_swing_JRadioButton$object	_jc_javax_swing_JRadioButton$object;

typedef struct _jc_javax_swing_JRadioButton$fields_struct	_jc_javax_swing_JRadioButton$fields_struct;
typedef const struct _jc_javax_swing_JRadioButton$vmethods	_jc_javax_swing_JRadioButton$vmethods;
typedef const struct _jc_javax_swing_JRadioButton$vtable	_jc_javax_swing_JRadioButton$vtable;
typedef const struct _jc_javax_swing_JRadioButton$vtype	_jc_javax_swing_JRadioButton$vtype;

// Class fields structure
struct _jc_javax_swing_JRadioButton$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRadioButton$fields_struct _jc_javax_swing_JRadioButton$class_fields;

// Constructors
extern void _jc_javax_swing_JRadioButton$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$14d08bc2d9c96919(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$642d788411804977(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$87ae54c77b157ee3(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$_init$8431f48b99fcfffb(_jc_env *, struct _jc_javax_swing_JRadioButton$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_JRadioButton$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_JRadioButton$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_JRadioButton$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JRadioButton$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRadioButton$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_javax_swing_JRadioButton$method_info$updateUI$46bebc7909e18fa1;

// Virtual methods structure
struct _jc_javax_swing_JRadioButton$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_JRadioButton$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JRadioButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JToggleButton$vmethods	javax_swing_JToggleButton;
	_jc_javax_swing_JRadioButton$vmethods	javax_swing_JRadioButton;
};

// Vtype
struct _jc_javax_swing_JRadioButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JRadioButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JRadioButton$refs {
    _jc_javax_swing_JRadioButton$sub_refs	javax_swing_JRadioButton;
    _jc_javax_swing_JToggleButton$sub_refs	javax_swing_JToggleButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRadioButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRadioButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JToggleButton$sub_nonrefs	javax_swing_JToggleButton;
    _jc_javax_swing_JRadioButton$sub_nonrefs	javax_swing_JRadioButton;
};

// Object instance structure
struct _jc_javax_swing_JRadioButton$object {
	_jc_javax_swing_JRadioButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRadioButton$vtype	*vtype;
	_jc_javax_swing_JRadioButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRadioButton$vtype _jc_javax_swing_JRadioButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRadioButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRadioButton$class_object;

#endif	/* _JC_javax_swing_JRadioButton_H_ */
